# API Reference

## watchmaker module

```eval_rst
.. automodule:: watchmaker
```

## watchmaker.cli module

```eval_rst
.. automodule:: watchmaker.cli
```

## watchmaker.logger module

```eval_rst
.. automodule:: watchmaker.logger
```

## watchmaker.managers module

```eval_rst
.. automodule:: watchmaker.managers
```

## watchmaker.managers.base module

```eval_rst
.. automodule:: watchmaker.managers.base
```

## watchmaker.managers.workers module

```eval_rst
.. automodule:: watchmaker.managers.workers
```

## watchmaker.workers module

```eval_rst
.. automodule:: watchmaker.workers
```

## watchmaker.workers.base module

```eval_rst
.. automodule:: watchmaker.workers.base
```

## watchmaker.workers.salt module

```eval_rst
.. automodule:: watchmaker.workers.salt
```

## watchmaker.workers.yum module

```eval_rst
.. automodule:: watchmaker.workers.yum
```
